from django.db import models

class Manifest(models.Model):
  month = models.CharField(max_length=3)
  year = models.IntegerField(max_length=4)
  filename = models.CharField(max_length=256)

  def __unicode__(self):
    return self.filename

TYPE_CHOICES = (
    ('Import', 'Import'),
    ('Export', 'Export'),
    ('Rexport', 'Rexport'),
    )

#['type', 'number', 'date', 'ship_name', 'captain', 'flag', 'trader', 'port', 'country']
class Ship(models.Model):
  manifest_file = models.ForeignKey(Manifest)
  bill_type = models.CharField(max_length=50, choices=TYPE_CHOICES)
  number = models.IntegerField(max_length=20)
  date = models.DateField()
  ship_name = models.CharField(max_length=255)
  ship_name_trans = models.CharField(max_length=255, blank=True, null=True)
  captain = models.CharField(max_length=255)
  captain_trans = models.CharField(max_length=255, blank=True, null=True)
  flag = models.CharField(max_length=255)
  owner = models.CharField(max_length=255)
  owner_trans = models.CharField(max_length=255, blank=True, null=True)
  port = models.CharField(max_length=255)
  country = models.CharField(max_length=255)

  def __unicode__(self):
    return "%d: %s" % (self.number, self.ship_name,)

#  class Meta:
#    ordering = ['number']

  def no_of_goods(self):
    return Good.objects.filter(ship=self).count()

#['description', 'package_type', 'no_of_packages', 'weight', 'value']
class Good(models.Model):
  ship = models.ForeignKey(Ship)
  description = models.TextField()
  description_string = models.TextField(blank=True, null=True)
  description_string_trans = models.TextField(blank=True, null=True)
  package_type = models.CharField(max_length=256)
  no_of_packages = models.IntegerField(max_length=20, null=True)
  weight = models.IntegerField(max_length=20, null=True)
  value = models.IntegerField(max_length=20, null=True)

  def __unicode__(self):
    return self.description


class Translation(models.Model):
    string = models.TextField(unique=True)
    string_trans = models.TextField(blank=True, null=True)
    looked_at = models.NullBooleanField(default=False)
#    user = models.ForeignKey(User)

    def __unicode__(self):
        return "%s: %s" % (self.string, self.string_trans,)

    class Meta:
        ordering = ('id',)
# Create your models here.
